@@ -3,8 +3,6 @@ from django.contrib.admin.filterspecs import AllValuesFilterSpec, FilterSpec
 from django.contrib.admin.util import unquote
 from django.contrib.admin.views.main import ChangeList, Paginator
 from django.core.cache import cache
-from django.forms.util import flatatt
-from django.http import HttpResponse
 from django.utils.encoding import force_unicode, smart_unicode
 from django.utils.html import escape
 from django.utils.safestring import mark_safe
@@ -14,7 +12,6 @@ from django import forms
 from djangodblog.models import ErrorBatch, Error
 from djangodblog.helpers import ImprovedExceptionReporter
 from djangodblog.settings import *
-from djangodblog.utils import JSONDictFormField
 
 import base64
 import re
@@ -38,11 +35,6 @@ class EfficientPaginator(Paginator):
 class EfficientChangeList(ChangeList):
     def get_results(self, request):
         paginator = EfficientPaginator(self.query_set, self.list_per_page)
-        # Get the number of objects, with admin filters applied.
-        result_count = paginator.count
-        
-        multi_page = result_count > self.list_per_page
-
         result_count = ''
 
         # Get the list of objects to display on this page.
@@ -55,7 +47,7 @@ class EfficientChangeList(ChangeList):
         self.result_count = result_count
         self.result_list = result_list
         self.can_show_all = False
-        self.multi_page = multi_page
+        self.multi_page = True
         self.paginator = paginator
 
 class EfficientModelAdmin(admin.ModelAdmin):
@@ -72,9 +64,6 @@ class CachedAllValuesFilterSpec(AllValuesFilterSpec):
             self.lookup_choices = list(model_admin.queryset(request).distinct().order_by(f.name).values_list(f.name, flat=True))
             cache.set(cache_key, self.lookup_choices, 60*5)
 
-    def title(self):
-        return self.field.verbose_name
-
     def choices(self, cl):
         yield {'selected': self.lookup_val is None,
                'query_string': cl.get_query_string({}, [self.field.name]),
