@@ -1,4 +1,5 @@
 from django.db import models
+from django.utils.encoding import smart_unicode
 from django.utils.translation import ugettext_lazy as _
 
 try:
@@ -10,6 +11,7 @@ import datetime
 
 from djangodblog.manager import DBLogManager
 from djangodblog.utils import JSONDictField
+from djangodblog.helpers import construct_checksum
 
 __all__ = ('Error', 'ErrorBatch')
 
@@ -37,8 +39,8 @@ class ErrorBatch(Model):
     # XXX: We're using the legacy column for `is_resolved` for status
     status          = models.PositiveIntegerField(default=0, db_column="is_resolved", choices=STATUS_LEVELS)
     times_seen      = models.PositiveIntegerField(default=1)
-    last_seen       = models.DateTimeField(default=datetime.datetime.now)
-    first_seen      = models.DateTimeField(default=datetime.datetime.now)
+    last_seen       = models.DateTimeField(default=datetime.datetime.now, db_index=True)
+    first_seen      = models.DateTimeField(default=datetime.datetime.now, db_index=True)
     url             = models.URLField(verify_exists=False, null=True, blank=True)
     server_name     = models.CharField(max_length=128, db_index=True)
     checksum        = models.CharField(max_length=32, db_index=True)
@@ -60,11 +62,16 @@ class ErrorBatch(Model):
         if len(url) > 60:
             url = url[:60] + '...'
         return url
-    shortened_url.short_description = "URL"
+    shortened_url.short_description = 'URL'
     shortened_url.admin_order_field = 'url'
-
+    
+    def full_url(self):
+        return self.data.get('url') or self.url
+    full_url.short_description = 'URL'
+    full_url.admin_order_field = 'url'
+    
     def error(self):
-        message = self.message
+        message = smart_unicode(self.message)
         if len(message) > 100:
             message = message[:97] + '...'
         if self.class_name:
@@ -77,14 +84,15 @@ class ErrorBatch(Model):
 
 class Error(Model):
     logger          = models.CharField(max_length=64, blank=True, default='root', db_index=True)
-    class_name      = models.CharField(_('type'), max_length=128, blank=True, null=True)
+    class_name      = models.CharField(_('type'), max_length=128, blank=True, null=True, db_index=True)
     level           = models.PositiveIntegerField(choices=LOG_LEVELS, default=logging.ERROR, blank=True, db_index=True)
     message         = models.TextField()
     traceback       = models.TextField(blank=True, null=True)
-    datetime        = models.DateTimeField(default=datetime.datetime.now)
+    datetime        = models.DateTimeField(default=datetime.datetime.now, db_index=True)
     url             = models.URLField(verify_exists=False, null=True, blank=True)
     data            = JSONDictField(blank=True, null=True)
     server_name     = models.CharField(max_length=128, db_index=True)
+    checksum        = models.CharField(max_length=32, db_index=True, null=True)
 
     objects         = DBLogManager()
 
@@ -93,7 +101,7 @@ class Error(Model):
         verbose_name_plural = 'Messages'
 
     def __unicode__(self):
-        return "%s: %s" % (self.class_name, self.message)
+        return "%s: %s" % (self.class_name, smart_unicode(self.message))
 
     def shortened_url(self):
         if not self.url:
@@ -102,11 +110,16 @@ class Error(Model):
         if len(url) > 60:
             url = url[:60] + '...'
         return url
-    shortened_url.short_description = "URL"
+    shortened_url.short_description = 'URL'
     shortened_url.admin_order_field = 'url'
+    
+    def full_url(self):
+        return self.data.get('url') or self.url
+    full_url.short_description = 'URL'
+    full_url.admin_order_field = 'url'
 
     def error(self):
-        message = self.message
+        message = smart_unicode(self.message)
         if len(message) > 100:
             message = message[:97] + '...'
         if self.class_name:
@@ -115,4 +128,9 @@ class Error(Model):
     error.short_description = 'Error'
 
     def get_absolute_url(self):
-        return self.url
\ No newline at end of file
+        return self.url
+    
+    def save(self, *args, **kwargs):
+        if not self.checksum:
+            self.checksum = construct_checksum(self)
+        super(Error, self).save(*args, **kwargs)
